@@ -1,5 +1,6 @@
 #include <Rcpp.h>
 #include "shared.h"
+// [[Rcpp::plugins(cpp11)]]
 
 using std::pow;
 using std::sqrt;
@@ -8,29 +9,25 @@ using std::exp;
 using std::log;
 using std::floor;
 using std::ceil;
-using std::sin;
-using std::cos;
-using std::tan;
-using std::atan;
-using Rcpp::IntegerVector;
 using Rcpp::NumericVector;
 using Rcpp::NumericMatrix;
 
 
-double pmf_bpois(double x, double y, double a, double b, double c) {
+inline double pmf_bpois(double x, double y, double a, double b, double c,
+                        bool& throw_warning) {
   
   if (ISNAN(x) || ISNAN(y) || ISNAN(a) || ISNAN(b) || ISNAN(c))
-    return NA_REAL;
-  
+    return x+y+a+b+c;
+
   if (a < 0.0 || b < 0.0 || c < 0.0) {
-    Rcpp::warning("NaNs produced");
+    throw_warning = true;
     return NAN;
   }
   
-  if (!isInteger(x) || x < 0.0)
+  if (!isInteger(x) || x < 0.0 || !R_FINITE(x) || !R_FINITE(y))
     return 0.0;
   
-  if (floor(y) != y) {
+  if (!isInteger(y, false)) {
     char msg[55];
     std::snprintf(msg, sizeof(msg), "non-integer y = %f", y);
     Rcpp::warning(msg);
@@ -42,19 +39,13 @@ double pmf_bpois(double x, double y, double a, double b, double c) {
   
   double tmp = exp(-(a+b+c)); 
   tmp *= (pow(a, x) / factorial(x)) * (pow(b, y) / factorial(y));
+  
+  double z = (x < y) ? x : y;
+  double c_ab = c/(a*b);
   double xy = 0.0;
   
-  double z;
-  if (x < y)
-    z = x;
-  else
-    z = y;
-  
-  double k = 0.0;
-  while (k < z) {
-    xy += R::choose(x, k) * R::choose(y, k) * factorial(k) * pow(c/(a*b), k);
-    k += 1.0;
-  }
+  for (double k = 0.0; k <= z; k += 1.0)
+    xy += R::choose(x, k) * R::choose(y, k) * factorial(k) * pow(c_ab, k);
   
   return tmp * xy;
 }
@@ -67,23 +58,32 @@ NumericVector cpp_dbpois(
     const NumericVector& a,
     const NumericVector& b,
     const NumericVector& c,
-    bool log_prob = false
+    const bool& log_prob = false
   ) {
   
-  int nx = x.length();
-  int ny = y.length();
-  int na = a.length();
-  int nb = b.length();
-  int nc = c.length();
-  int Nmax = Rcpp::max(IntegerVector::create(nx, ny, na, nb, nc));
+  int Nmax = std::max({
+    x.length(),
+    y.length(),
+    a.length(),
+    b.length(),
+    c.length()
+  });
   NumericVector p(Nmax);
   
+  bool throw_warning = false;
+  
+  if (x.length() != y.length())
+    Rcpp::stop("lengths of x and y differ");
+  
   for (int i = 0; i < Nmax; i++)
-    p[i] = pmf_bpois(x[i % nx], y[i % ny], a[i % na], b[i % nb], c[i % nc]);
+    p[i] = pmf_bpois(GETV(x, i), GETV(y, i), GETV(a, i),
+                     GETV(b, i), GETV(c, i), throw_warning);
   
   if (log_prob)
-    for (int i = 0; i < Nmax; i++)
-      p[i] = log(p[i]);
+    p = Rcpp::log(p);
+  
+  if (throw_warning)
+    Rcpp::warning("NaNs produced");
   
   return p;
 }
@@ -91,35 +91,35 @@ NumericVector cpp_dbpois(
 
 // [[Rcpp::export]]
 NumericMatrix cpp_rbpois(
-    const int n,
+    const int& n,
     const NumericVector& a,
     const NumericVector& b,
     const NumericVector& c
   ) {
   
-  double u, v, w;
-  int na = a.length();
-  int nb = b.length();
-  int nc = c.length();
   NumericMatrix x(n, 2);
+  double u, v, w;
+  
+  bool throw_warning = false;
   
   for (int i = 0; i < n; i++) {
-    if (ISNAN(a[i % na]) || ISNAN(b[i % nb]) || ISNAN(c[i % nc])) {
+    if (ISNAN(GETV(a, i)) || ISNAN(GETV(b, i)) || ISNAN(GETV(c, i)) || 
+        GETV(a, i) < 0.0 || GETV(b, i) < 0.0 || GETV(c, i) < 0.0) {
+      throw_warning = true;
       x(i, 0) = NA_REAL;
       x(i, 1) = NA_REAL;
-    } else if (a[i % na] < 0.0 || b[i % nb] < 0.0 || c[i % nc] < 0.0) {
-      Rcpp::warning("NaNs produced");
-      x(i, 0) = NAN;
-      x(i, 1) = NAN;
     } else {
-      u = R::rpois(a[i % na]);
-      v = R::rpois(b[i % nb]);
-      w = R::rpois(c[i % nc]);
+      u = R::rpois(GETV(a, i));
+      v = R::rpois(GETV(b, i));
+      w = R::rpois(GETV(c, i));
       x(i, 0) = u+w;
       x(i, 1) = v+w;
     }
   }
 
+  if (throw_warning)
+    Rcpp::warning("NAs produced");
+  
   return x;
 }
 
