@@ -1,5 +1,6 @@
 #include <Rcpp.h>
 #include "shared.h"
+// [[Rcpp::plugins(cpp11)]]
 
 using std::pow;
 using std::sqrt;
@@ -8,13 +9,7 @@ using std::exp;
 using std::log;
 using std::floor;
 using std::ceil;
-using std::sin;
-using std::cos;
-using std::tan;
-using std::atan;
-using Rcpp::IntegerVector;
 using Rcpp::NumericVector;
-using Rcpp::NumericMatrix;
 
 
 /*
@@ -40,9 +35,10 @@ using Rcpp::NumericMatrix;
  *
  */
 
-double pdf_gev(double x, double mu, double sigma, double xi) {
+inline double pdf_gev(double x, double mu, double sigma,
+                      double xi, bool& throw_warning) {
   if (ISNAN(x) || ISNAN(mu) || ISNAN(sigma) || ISNAN(xi))
-    return NA_REAL;
+    return x+mu+sigma+xi;
   if (sigma <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
@@ -58,9 +54,10 @@ double pdf_gev(double x, double mu, double sigma, double xi) {
   }
 }
 
-double cdf_gev(double x, double mu, double sigma, double xi) {
+inline double cdf_gev(double x, double mu, double sigma,
+                      double xi, bool& throw_warning) {
   if (ISNAN(x) || ISNAN(mu) || ISNAN(sigma) || ISNAN(xi))
-    return NA_REAL;
+    return x+mu+sigma+xi;
   if (sigma <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
@@ -76,21 +73,35 @@ double cdf_gev(double x, double mu, double sigma, double xi) {
   }
 }
 
-double invcdf_gev(double p, double mu, double sigma, double xi) {
+inline double invcdf_gev(double p, double mu, double sigma,
+                         double xi, bool& throw_warning) {
   if (ISNAN(p) || ISNAN(mu) || ISNAN(sigma) || ISNAN(xi))
-    return NA_REAL;
-  if (sigma <= 0.0 || p < 0.0 || p > 1.0) {
+    return p+mu+sigma+xi;
+  if (sigma <= 0.0 || !VALID_PROB(p)) {
     Rcpp::warning("NaNs produced");
     return NAN;
   }
   if (p == 1.0)
-    return INFINITY;
+    return R_PosInf;
   if (xi != 0.0)
     return mu - sigma/xi * (1.0 - pow(-log(p), -xi));
   else
     return mu - sigma * log(-log(p));
 }
 
+inline double rng_gev(double mu, double sigma, double xi,
+                      bool& throw_warning) {
+  if (ISNAN(mu) || ISNAN(sigma) || ISNAN(xi) || sigma <= 0.0) {
+    Rcpp::warning("NAs produced");
+    return NA_REAL;
+  }
+  double u = rng_unif();
+  if (xi != 0.0)
+    return mu - sigma/xi * (1.0 - pow(-log(u), -xi));
+  else
+    return mu - sigma * log(-log(u));
+}
+
 
 // [[Rcpp::export]]
 NumericVector cpp_dgev(
@@ -98,22 +109,29 @@ NumericVector cpp_dgev(
     const NumericVector& mu,
     const NumericVector& sigma,
     const NumericVector& xi,
-    bool log_prob = false
+    const bool& log_prob = false
   ) {
 
-  int n  = x.length();
-  int nm = mu.length();
-  int ns = sigma.length();
-  int nx = xi.length();
-  int Nmax = Rcpp::max(IntegerVector::create(n, nm, ns, nx));
+  int Nmax = std::max({
+    x.length(),
+    mu.length(),
+    sigma.length(),
+    xi.length()
+  });
   NumericVector p(Nmax);
+  
+  bool throw_warning = false;
 
   for (int i = 0; i < Nmax; i++)
-    p[i] = pdf_gev(x[i % n], mu[i % nm], sigma[i % ns], xi[i % nx]);
+    p[i] = pdf_gev(GETV(x, i), GETV(mu, i),
+                   GETV(sigma, i), GETV(xi, i),
+                   throw_warning);
 
   if (log_prob)
-    for (int i = 0; i < Nmax; i++)
-      p[i] = log(p[i]);
+    p = Rcpp::log(p);
+  
+  if (throw_warning)
+    Rcpp::warning("NaNs produced");
 
   return p;
 }
@@ -128,23 +146,29 @@ NumericVector cpp_pgev(
     bool lower_tail = true, bool log_prob = false
   ) {
 
-  int n  = x.length();
-  int nm = mu.length();
-  int ns = sigma.length();
-  int nx = xi.length();
-  int Nmax = Rcpp::max(IntegerVector::create(n, nm, ns, nx));
+  int Nmax = std::max({
+    x.length(),
+    mu.length(),
+    sigma.length(),
+    xi.length()
+  });
   NumericVector p(Nmax);
+  
+  bool throw_warning = false;
 
   for (int i = 0; i < Nmax; i++)
-    p[i] = cdf_gev(x[i % n], mu[i % nm], sigma[i % ns], xi[i % nx]);
+    p[i] = cdf_gev(GETV(x, i), GETV(mu, i),
+                   GETV(sigma, i), GETV(xi, i),
+                   throw_warning);
 
   if (!lower_tail)
-    for (int i = 0; i < Nmax; i++)
-      p[i] = 1.0 - p[i];
-
+    p = 1.0 - p;
+  
   if (log_prob)
-    for (int i = 0; i < Nmax; i++)
-      p[i] = log(p[i]);
+    p = Rcpp::log(p);
+  
+  if (throw_warning)
+    Rcpp::warning("NaNs produced");
 
   return p;
 }
@@ -159,24 +183,30 @@ NumericVector cpp_qgev(
     bool lower_tail = true, bool log_prob = false
   ) {
 
-  int n  = p.length();
-  int nm = mu.length();
-  int ns = sigma.length();
-  int nx = xi.length();
-  int Nmax = Rcpp::max(IntegerVector::create(n, nm, ns, nx));
+  int Nmax = std::max({
+    p.length(),
+    mu.length(),
+    sigma.length(),
+    xi.length()
+  });
   NumericVector q(Nmax);
   NumericVector pp = Rcpp::clone(p);
+  
+  bool throw_warning = false;
 
   if (log_prob)
-    for (int i = 0; i < n; i++)
-      pp[i] = exp(pp[i]);
-
+    pp = Rcpp::exp(pp);
+  
   if (!lower_tail)
-    for (int i = 0; i < n; i++)
-      pp[i] = 1.0 - pp[i];
+    pp = 1.0 - pp;
 
   for (int i = 0; i < Nmax; i++)
-    q[i] = invcdf_gev(pp[i % n], mu[i % nm], sigma[i % ns], xi[i % nx]);
+    q[i] = invcdf_gev(GETV(pp, i), GETV(mu, i),
+                      GETV(sigma, i), GETV(xi, i),
+                      throw_warning);
+  
+  if (throw_warning)
+    Rcpp::warning("NaNs produced");
 
   return q;
 }
@@ -184,22 +214,22 @@ NumericVector cpp_qgev(
 
 // [[Rcpp::export]]
 NumericVector cpp_rgev(
-    const int n,
+    const int& n,
     const NumericVector& mu,
     const NumericVector& sigma,
     const NumericVector& xi
   ) {
 
-  double u;
-  int nm = mu.length();
-  int ns = sigma.length();
-  int nx = xi.length();
   NumericVector x(n);
 
-  for (int i = 0; i < n; i++) {
-    u = rng_unif();
-    x[i] = invcdf_gev(u, mu[i % nm], sigma[i % ns], xi[i % nx]);
-  }
+  bool throw_warning = false;
+  
+  for (int i = 0; i < n; i++)
+    x[i] = rng_gev(GETV(mu, i), GETV(sigma, i),
+                   GETV(xi, i), throw_warning);
+  
+  if (throw_warning)
+    Rcpp::warning("NAs produced");
 
   return x;
 }
