@@ -1,5 +1,6 @@
 #include <Rcpp.h>
 #include "shared.h"
+// [[Rcpp::plugins(cpp11)]]
 
 using std::pow;
 using std::sqrt;
@@ -8,13 +9,7 @@ using std::exp;
 using std::log;
 using std::floor;
 using std::ceil;
-using std::sin;
-using std::cos;
-using std::tan;
-using std::atan;
-using Rcpp::IntegerVector;
 using Rcpp::NumericVector;
-using Rcpp::NumericMatrix;
 
 
 /*
@@ -39,51 +34,64 @@ using Rcpp::NumericMatrix;
 */
 
 
-double pdf_gompertz(double x, double a, double b) {
+inline double pdf_gompertz(double x, double a, double b,
+                           bool& throw_warning) {
   if (ISNAN(x) || ISNAN(a) || ISNAN(b))
-    return NA_REAL;
+    return x+a+b;
   if (a <= 0.0 || b <= 0.0) {
-    Rcpp::warning("NaNs produced");
+    throw_warning = true;
     return NAN;
   }
-  if (x < 0.0 || std::isinf(x))
+  if (x < 0.0 || !R_FINITE(x))
     return 0.0;
   return a * exp(b*x - a/b * (exp(b*x) - 1.0));
 }
 
-double cdf_gompertz(double x, double a, double b) {
+inline double cdf_gompertz(double x, double a, double b,
+                           bool& throw_warning) {
   if (ISNAN(x) || ISNAN(a) || ISNAN(b))
-    return NA_REAL;
+    return x+a+b;
   if (a <= 0.0 || b <= 0.0) {
-    Rcpp::warning("NaNs produced");
+    throw_warning = true;
     return NAN;
   }
-  if (std::isinf(x))
-    return 1.0;
   if (x < 0.0)
     return 0.0;
+  if (!R_FINITE(x))
+    return 1.0;
   return 1.0 - exp(-a/b * (exp(b*x) - 1.0));
 }
 
-double invcdf_gompertz(double p, double a, double b) {
+inline double invcdf_gompertz(double p, double a, double b,
+                              bool& throw_warning) {
   if (ISNAN(p) || ISNAN(a) || ISNAN(b))
-    return NA_REAL;
-  if (a <= 0.0 || b <= 0.0 || p < 0.0 || p > 1.0) {
-    Rcpp::warning("NaNs produced");
+    return p+a+b;
+  if (a <= 0.0 || b <= 0.0 || !VALID_PROB(p)) {
+    throw_warning = true;
     return NAN;
   }
-  return 1.0/b * log(1.0 - b/a * log(1.0-p));
+  return log(1.0 - b/a * log(1.0-p)) / b;
 }
 
-double logpdf_gompertz(double x, double a, double b) {
-  if (ISNAN(x) || ISNAN(a) || ISNAN(b))
+inline double rng_gompertz(double a, double b, bool& throw_warning) {
+  if (ISNAN(a) || ISNAN(b) || a <= 0.0 || b <= 0.0) {
+    throw_warning = true;
     return NA_REAL;
+  }
+  double u = rng_unif();
+  return log(1.0 - b/a * log(u)) / b;
+}
+
+inline double logpdf_gompertz(double x, double a, double b,
+                              bool& throw_warning) {
+  if (ISNAN(x) || ISNAN(a) || ISNAN(b))
+    return x+a+b;
   if (a <= 0.0 || b <= 0.0) {
-    Rcpp::warning("NaNs produced");
+    throw_warning = true;
     return NAN;
   }
-  if (x < 0.0 || std::isinf(x))
-    return -INFINITY;
+  if (x < 0.0 || !R_FINITE(x))
+    return R_NegInf;
   return log(a) + (b*x - a/b * (exp(b*x) - 1.0));
 }
 
@@ -96,18 +104,24 @@ NumericVector cpp_dgompertz(
     bool log_prob = false
   ) {
 
-  int n  = x.length();
-  int na = a.length();
-  int nb = b.length();
-  int Nmax = Rcpp::max(IntegerVector::create(n, na, nb));
+  int Nmax = std::max({
+    x.length(),
+    a.length(),
+    b.length()
+  });
   NumericVector p(Nmax);
+  
+  bool throw_warning = false;
 
   for (int i = 0; i < Nmax; i++)
-    p[i] = logpdf_gompertz(x[i % n], a[i % na], b[i % nb]);
+    p[i] = logpdf_gompertz(GETV(x, i), GETV(a, i),
+                           GETV(b, i), throw_warning);
 
   if (!log_prob)
-    for (int i = 0; i < Nmax; i++)
-      p[i] = exp(p[i]);
+    p = Rcpp::exp(p);
+  
+  if (throw_warning)
+    Rcpp::warning("NaNs produced");
 
   return p;
 }
@@ -118,25 +132,31 @@ NumericVector cpp_pgompertz(
     const NumericVector& x,
     const NumericVector& a,
     const NumericVector& b,
-    bool lower_tail = true, bool log_prob = false
+    const bool& lower_tail = true,
+    const bool& log_prob = false
   ) {
 
-  int n  = x.length();
-  int na = a.length();
-  int nb = b.length();
-  int Nmax = Rcpp::max(IntegerVector::create(n, na, nb));
+  int Nmax = std::max({
+    x.length(),
+    a.length(),
+    b.length()
+  });
   NumericVector p(Nmax);
+  
+  bool throw_warning = false;
 
   for (int i = 0; i < Nmax; i++)
-    p[i] = cdf_gompertz(x[i % n], a[i % na], b[i % nb]);
+    p[i] = cdf_gompertz(GETV(x, i), GETV(a, i),
+                        GETV(b, i), throw_warning);
 
   if (!lower_tail)
-    for (int i = 0; i < Nmax; i++)
-      p[i] = 1.0 - p[i];
-
+    p = 1.0 - p;
+  
   if (log_prob)
-    for (int i = 0; i < Nmax; i++)
-      p[i] = log(p[i]);
+    p = Rcpp::log(p);
+  
+  if (throw_warning)
+    Rcpp::warning("NaNs produced");
 
   return p;
 }
@@ -147,26 +167,32 @@ NumericVector cpp_qgompertz(
     const NumericVector& p,
     const NumericVector& a,
     const NumericVector& b,
-    bool lower_tail = true, bool log_prob = false
+    const bool& lower_tail = true,
+    const bool& log_prob = false
   ) {
 
-  int n  = p.length();
-  int na = a.length();
-  int nb = b.length();
-  int Nmax = Rcpp::max(IntegerVector::create(n, na, nb));
+  int Nmax = std::max({
+    p.length(),
+    a.length(),
+    b.length()
+  });
   NumericVector q(Nmax);
   NumericVector pp = Rcpp::clone(p);
   
+  bool throw_warning = false;
+  
   if (log_prob)
-    for (int i = 0; i < n; i++)
-      pp[i] = exp(pp[i]);
-
+    pp = Rcpp::exp(pp);
+  
   if (!lower_tail)
-    for (int i = 0; i < n; i++)
-      pp[i] = 1.0 - pp[i];
+    pp = 1.0 - pp;
 
   for (int i = 0; i < Nmax; i++)
-    q[i] = invcdf_gompertz(pp[i % n], a[i % na], b[i % nb]);
+    q[i] = invcdf_gompertz(GETV(pp, i), GETV(a, i),
+                           GETV(b, i), throw_warning);
+  
+  if (throw_warning)
+    Rcpp::warning("NaNs produced");
 
   return q;
 }
@@ -174,20 +200,21 @@ NumericVector cpp_qgompertz(
 
 // [[Rcpp::export]]
 NumericVector cpp_rgompertz(
-    const int n,
+    const int& n,
     const NumericVector& a,
     const NumericVector& b
   ) {
 
-  double u;
-  int na = a.length();
-  int nb = b.length();
   NumericVector x(n);
+  
+  bool throw_warning = false;
 
-  for (int i = 0; i < n; i++) {
-    u = rng_unif();
-    x[i] = invcdf_gompertz(u, a[i % na], b[i % nb]);
-  }
+  for (int i = 0; i < n; i++)
+    x[i] = rng_gompertz(GETV(a, i), GETV(b, i),
+                        throw_warning);
+  
+  if (throw_warning)
+    Rcpp::warning("NAs produced");
 
   return x;
 }
