@@ -1,5 +1,6 @@
 #include <Rcpp.h>
 #include "shared.h"
+// [[Rcpp::plugins(cpp11)]]
 
 using std::pow;
 using std::sqrt;
@@ -8,20 +9,16 @@ using std::exp;
 using std::log;
 using std::floor;
 using std::ceil;
-using std::sin;
-using std::cos;
+using Rcpp::NumericVector;
 using std::tan;
 using std::atan;
-using Rcpp::IntegerVector;
-using Rcpp::NumericVector;
-using Rcpp::NumericMatrix;
 
 
-double pdf_hcauchy(double x, double sigma) {
+inline double pdf_hcauchy(double x, double sigma, bool& throw_warning) {
   if (ISNAN(x) || ISNAN(sigma))
-    return NA_REAL;
+    return x+sigma;
   if (sigma <= 0.0) {
-    Rcpp::warning("NaNs produced");
+    throw_warning = true;
     return NAN;
   }
   if (x < 0.0)
@@ -29,11 +26,11 @@ double pdf_hcauchy(double x, double sigma) {
   return 2.0/(M_PI*(1.0 + pow(x/sigma, 2.0)))/sigma;
 }
 
-double cdf_hcauchy(double x, double sigma) {
+double cdf_hcauchy(double x, double sigma, bool& throw_warning) {
   if (ISNAN(x) || ISNAN(sigma))
-    return NA_REAL;
+    return x+sigma;
   if (sigma <= 0.0) {
-    Rcpp::warning("NaNs produced");
+    throw_warning = true;
     return NAN;
   }
   if (x < 0.0)
@@ -41,22 +38,21 @@ double cdf_hcauchy(double x, double sigma) {
   return 2.0/M_PI * atan(x/sigma);
 }
 
-double invcdf_hcauchy(double p, double sigma) {
+inline double invcdf_hcauchy(double p, double sigma,
+                             bool& throw_warning) {
   if (ISNAN(p) || ISNAN(sigma))
-    return NA_REAL;
-  if (sigma <= 0.0 || p < 0.0 || p > 1.0) {
-    Rcpp::warning("NaNs produced");
+    return p+sigma;
+  if (sigma <= 0.0 || !VALID_PROB(p)) {
+    throw_warning = true;
     return NAN;
   }
   return sigma * tan((M_PI*p)/2.0);
 }
 
-double rng_hcauchy(double sigma) {
-  if (ISNAN(sigma))
+inline double rng_hcauchy(double sigma, bool& throw_warning) {
+  if (ISNAN(sigma) || sigma <= 0.0) {
+    throw_warning = true;
     return NA_REAL;
-  if (sigma <= 0.0) {
-    Rcpp::warning("NaNs produced");
-    return NAN;
   }
   return abs(R::rcauchy(0.0, sigma));
 }
@@ -66,20 +62,26 @@ double rng_hcauchy(double sigma) {
 NumericVector cpp_dhcauchy(
     const NumericVector& x,
     const NumericVector& sigma,
-    bool log_prob = false
-) {
+    const bool& log_prob = false
+  ) {
   
-  int n  = x.length();
-  int ns = sigma.length();
-  int Nmax = Rcpp::max(IntegerVector::create(n, ns));
+  int Nmax = std::max({
+    x.length(),
+    sigma.length()
+  });
   NumericVector p(Nmax);
   
+  bool throw_warning = false;
+  
   for (int i = 0; i < Nmax; i++)
-    p[i] = pdf_hcauchy(x[i % n], sigma[i % ns]);
+    p[i] = pdf_hcauchy(GETV(x, i), GETV(sigma, i),
+                       throw_warning);
   
   if (log_prob)
-    for (int i = 0; i < Nmax; i++)
-      p[i] = log(p[i]);
+    p = Rcpp::log(p);
+  
+  if (throw_warning)
+    Rcpp::warning("NaNs produced");
   
   return p;
 }
@@ -90,23 +92,28 @@ NumericVector cpp_phcauchy(
     const NumericVector& x,
     const NumericVector& sigma,
     bool lower_tail = true, bool log_prob = false
-) {
+  ) {
   
-  int n  = x.length();
-  int ns = sigma.length();
-  int Nmax = Rcpp::max(IntegerVector::create(n, ns));
+  int Nmax = std::max({
+    x.length(),
+    sigma.length()
+  });
   NumericVector p(Nmax);
   
+  bool throw_warning = false;
+  
   for (int i = 0; i < Nmax; i++)
-    p[i] = cdf_hcauchy(x[i % n], sigma[i % ns]);
+    p[i] = cdf_hcauchy(GETV(x, i), GETV(sigma, i),
+                       throw_warning);
   
   if (!lower_tail)
-    for (int i = 0; i < Nmax; i++)
-      p[i] = 1.0 - p[i];
+    p = 1.0 - p;
   
   if (log_prob)
-    for (int i = 0; i < Nmax; i++)
-      p[i] = log(p[i]);
+    p = Rcpp::log(p);
+  
+  if (throw_warning)
+    Rcpp::warning("NaNs produced");
   
   return p;
 }
@@ -116,25 +123,31 @@ NumericVector cpp_phcauchy(
 NumericVector cpp_qhcauchy(
     const NumericVector& p,
     const NumericVector& sigma,
-    bool lower_tail = true, bool log_prob = false
-) {
+    const bool& lower_tail = true,
+    const bool& log_prob = false
+  ) {
   
-  int n  = p.length();
-  int ns = sigma.length();
-  int Nmax = Rcpp::max(IntegerVector::create(n, ns));
+  int Nmax = std::max({
+    p.length(),
+    sigma.length()
+  });
   NumericVector q(Nmax);
   NumericVector pp = Rcpp::clone(p);
   
+  bool throw_warning = false;
+  
   if (log_prob)
-    for (int i = 0; i < n; i++)
-      pp[i] = exp(pp[i]);
+    pp = Rcpp::exp(pp);
   
   if (!lower_tail)
-    for (int i = 0; i < n; i++)
-      pp[i] = 1.0 - pp[i];
+    pp = 1.0 - pp;
   
   for (int i = 0; i < Nmax; i++)
-    q[i] = invcdf_hcauchy(pp[i % n], sigma[i % ns]);
+    q[i] = invcdf_hcauchy(GETV(pp, i), GETV(sigma, i),
+                          throw_warning);
+  
+  if (throw_warning)
+    Rcpp::warning("NaNs produced");
   
   return q;
 }
@@ -142,15 +155,19 @@ NumericVector cpp_qhcauchy(
 
 // [[Rcpp::export]]
 NumericVector cpp_rhcauchy(
-    const int n,
+    const int& n,
     const NumericVector& sigma
-) {
+  ) {
   
-  int ns = sigma.length();
   NumericVector x(n);
   
+  bool throw_warning = false;
+  
   for (int i = 0; i < n; i++)
-    x[i] = rng_hcauchy(sigma[i % ns]);
+    x[i] = rng_hcauchy(GETV(sigma, i), throw_warning);
+  
+  if (throw_warning)
+    Rcpp::warning("NAs produced");
   
   return x;
 }
